X-Git-Url: https://git.rapsys.eu/packbundle/blobdiff_plain/017fca0b76b793ae2c5aa1778c31ecc2d6de14df..780564d1998c2e41b4f9a145b5191a66dbaf6ed4:/RapsysPackBundle.php

diff --git a/RapsysPackBundle.php b/RapsysPackBundle.php
index 7be0f82..4ad24d4 100644
--- a/RapsysPackBundle.php
+++ b/RapsysPackBundle.php
@@ -11,13 +11,23 @@
 
 namespace Rapsys\PackBundle;
 
-use Symfony\Component\DependencyInjection\Container;
+use Symfony\Component\DependencyInjection\Extension\ExtensionInterface;
 use Symfony\Component\HttpKernel\Bundle\Bundle;
 
+use Rapsys\PackBundle\DependencyInjection\RapsysPackExtension;
+
 /**
  * {@inheritdoc}
  */
 class RapsysPackBundle extends Bundle {
+	/**
+	 * {@inheritdoc}
+	 */
+	public function getContainerExtension(): ?ExtensionInterface {
+		//Return created container extension
+		return $this->createContainerExtension();
+	}
+
 	/**
 	 * Return bundle alias
 	 *
@@ -43,7 +53,17 @@ class RapsysPackBundle extends Bundle {
 			$bpos = strlen(static::class) - $npos;
 		}
 
-		//Return underscored lowercase bundle alias
-		return Container::underscore(substr(static::class, $npos, $bpos));
+		//Return lowercase bundle alias
+		return strtolower(substr(static::class, $npos, $bpos));
+	}
+
+	/**
+	 * Return bundle version
+	 *
+	 * @return string The bundle version
+	 */
+	public static function getVersion(): string {
+		//Return version
+		return '0.4.0';
 	}
 }